==> hermes-6.0.2.31.tar.gz: hermes-6.0.2.31/app/serializers/hermes/required_document_serializer.rb <==
# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class RequiredDocumentSerializer < Hermes::ApplicationSerializer
    type 'required_documents'

    attributes :nature,
               :type,
               :label,
               :type_ihm,
               :category,
               :is_required_for_nud,
               :is_required_for_consultation,
               :is_required_for_application,
               :is_for_main_applicant,
               :dependent_infos,
               :disability_index,
               :applicant,
               :ihm_order,              
               :status,
               :status_id,
               :status_updated_at,
               :old_status,
               :status_history,
               :or_required_document_types,
               :declared

    def added_to_object_cache_key
      current_user&.id
    end

    def check_if_new_name(type)
      new_name_hash = {
        "Avis d'imposition N-1" => "Avis d'imposition 2021 sur les revenus de l'année 2020" ,
        "Avis d'imposition N-2" => "Avis d'imposition 2020 sur les revenus de l'année 2019" ,
      }
        new_name_hash[type] || type
    end
    
    def status
      object.status  unless @instance_options[:hide_status]
    end
    

   def status_history
     Hermes::Status.where(object_id: object.id).limit(5).order_by(created_at: -1)  unless @instance_options[:hide_status]
   end
    
    def type
      splitted_type = object.type.split("####")
    
      if (splitted_type[1])
        check_if_new_name(splitted_type[1])
      else
        splitted_type2 = object.type.split("****")
        if (splitted_type2[1])
          check_if_new_name(splitted_type2[1])
        else
          check_if_new_name(object.type)
          end
      end
    end
    
    def dependent_infos
      splitted_type = object.type.split("####")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end
    
    def disability_index
      splitted_type = object.type.split("****")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end
   
    
    def is_required_for_nud
      folder_id = @instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_nud.include? (folder_id)
    end
    
    def is_required_for_consultation
      folder_id = @instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_consultation.include? (folder_id)
    end
    
    def is_required_for_application
      folder_id = @instance_options[:folder_id]
      return unless folder_id
      object.folder_where_is_required_for_application.include? (folder_id)
    end
    
    def is_for_main_applicant
      main_applicant_id = @instance_options[:main_applicant_id]
      return unless main_applicant_id
      
      (object.applicant.id.to_s == main_applicant_id.to_s)
    end
    
    def applicant
      return nil unless object.applicant
      Hermes::ApplicantSerializer.new(
        object.applicant,
        scope: scope,
        root: false
      )
    end
  end
end

==> hermes-6.0.3.14.tar.gz: hermes-6.0.3.14/app/serializers/hermes/required_document_serializer.rb <==
# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class RequiredDocumentSerializer < Hermes::ApplicationSerializer
    type 'required_documents'

    attributes :nature,
               :type,
               :category,
               :is_for_main_applicant,
               :dependent_first_name,
               :dependent_last_name,
               :disability_index,
               :applicant_id,
               :applicant_full_name
    

    def added_to_object_cache_key
      current_user&.id
    end

    def check_if_new_name(type)
      new_name_hash = {
        "Avis d'imposition N-1" => "Avis d'imposition 2021 sur les revenus de l'année 2020" ,
        "Avis d'imposition N-2" => "Avis d'imposition 2020 sur les revenus de l'année 2019" ,
      }
        new_name_hash[type] || type
    end
    
    def type
      splitted_type = object.type.split("####")
    
      if (splitted_type[1])
        check_if_new_name(splitted_type[1])
      else
        splitted_type2 = object.type.split("****")
        if (splitted_type2[1])
          check_if_new_name(splitted_type2[1])
        else
          check_if_new_name(object.type)
          end
      end
    end
    
    def dependent_infos
      splitted_type = object.type.split("####")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end

    def disability_index
      splitted_type = object.type.split("****")
      if (splitted_type[1])
        return JSON(splitted_type[0])
      else
        nil
      end
    end

    def dependent_first_name
      dependent_infos && dependent_infos["first_name"]
    end

    def dependent_last_name
      dependent_infos && dependent_infos["last_name"]
    end

    def applicant_full_name
      Hermes::Applicant.find(object.applicant_id)&.full_name
    end 

    def is_for_main_applicant
      main_applicant_id = @instance_options[:main_applicant_id]
      return unless main_applicant_id
      
      (object.applicant.id.to_s == main_applicant_id.to_s)
    end

  end
end
